# PyMISPWarningLists

[![Build Status](https://travis-ci.org/MISP/PyMISPWarningLists.svg?branch=master)](https://travis-ci.org/MISP/PyMISPWarningLists)
[![codecov.io](https://codecov.io/github/MISP/PyMISPWarningLists/coverage.svg?branch=master)](https://codecov.io/github/MISP/PyMISPWarningLists?branch=master)

Pythonic way to work with the warning lists defined there: https://github.com/MISP/misp-warninglists

# Installation

`pip install pymispwarninglists`

# Usage

Warning lists are represented as immutable Python dictionaries.

